# Babern Engine

<a href="https://babern.org"><p align="center">
<img height=100 src="./babern.png"/>

</p></a>
<p align="center">
  <strong>Next Geneneration Engine 🚀</strong>
</p>
<h3 align="center">
  <a href="https://github.com/Ardustri/babern/blob/master/CONTRIBUTING.md">Contribute</a>
  <span> · </span>
  <a href="https://babern.org/c/docs">Documentation</a>
</h3>

---

## Structure

<!--
| Codebase               |                  Description                   |
| :--------------------- | :--------------------------------------------: |
| [kousa](kousa)         |                   Elixir API                   |
| [shawarma](shawarma)   |                  Voice Server                  |
| [dinner](dinner)       |             Puppeteer shenanigans              |
| [baklava](baklava)     |                Electron Wrapper                |
| [pilaf](pilaf)         |                React Native App                |
| [kibbeh](kibbeh)       |                Next.js frontend                |
| [kebab](kebab)         |                   API Client                   |
| [dolma](dolma)         |             Chat Token Transcoder              |
| [globalkey](globalkey) | [Baklava](baklava)'s Global Keystroke Listener |
-->

## Branches

- dev -> pr this branch for everything
- master -> don't touch, this is what's running in prod

## Contributions

Babern is open to contributions, but I recommend creating an issue or replying in a comment to let me know what you are working on first that way we don't overwrite each other.

Please read [CONTRIBUTING.md](https://github.com/Ardustri/babern/blob/master/CONTRIBUTING.md) for details on this project.

## Code of Conduct

Please read [CODE_OF_CONDUCT.md](https://github.com/Ardustri/babern/blob/master/CODE_OF_CONDUCT.MD) for details on our code of conduct.

## How to run locally

Check <a href="https://github.com/Ardustri/babern/blob/master">here</a> on how to run locally</a>
